==> debian_interfaces_parser-0.0.1.tar.gz: debian_interfaces_parser-0.0.1/debian_interfaces_parser/iface.py <==
# -*- coding: utf-8 -*-


class InvalidIface(RuntimeError):
    pass


class Iface(object):
    def __init__(self, name, src):
        self.src = src  # static or dhcp or loopback
        self.name = name
        self.netmask = None
        self.gateway = None
        self.dns_nameservers = []
        self.address = None
        self.wpa_ssid = None
        self.wpa_psk = None
        self.auto = False

    def dump(self):
        result = ''
        if self.auto:
            result += "auto {name}\n".format(name=self.name)
        result += "iface {name} inet {src}\n".format(name=self.name, src=self.src)

        if self.wpa_ssid and self.wpa_psk:
            result += "  wpa-ssid {s}\n".format(s=self.wpa_ssid)
            result += "  wpa-psk {s}\n".format(s=self.wpa_psk)

        if self.src == 'dhcp' or self.src == 'loopback':
            return result

        self.validate()

        result += "  address {s}\n".format(s=self.address)
        result += "  netmask {s}\n".format(s=self.netmask)

        if self.gateway:
            result += "  gateway {s}\n".format(s=self.gateway)

        if len(self.dns_nameservers) > 0:
            result += "  dns-nameservers {s}\n".format(s=', '.join(self.dns_nameservers))

        return result

    def validate(self):
        if self.src == 'static':
            if not self.address:
                raise InvalidIface('static interface must have address')
            if not self.netmask:
                raise InvalidIface('static interface must have netmask')

==> debian_interfaces_parser-0.0.2.tar.gz: debian_interfaces_parser-0.0.2/debian_interfaces_parser/iface.py <==
# -*- coding: utf-8 -*-


class InvalidIface(RuntimeError):
    pass


class Iface(object):
    def __init__(self, name, src):
        self.src = src  # static or dhcp or loopback
        self.name = name
        self.netmask = None
        self.gateway = None
        self.dns_nameservers = []
        self.address = None
        self.wpa_ssid = None
        self.wpa_psk = None
        self.auto = False

    def dump(self):
        result = ''
        if self.auto:
            result += "auto {name}\n".format(name=self.name)
        result += "iface {name} inet {src}\n".format(name=self.name, src=self.src)

        if self.wpa_ssid and self.wpa_psk:
            result += "  wpa-ssid {s}\n".format(s=self.wpa_ssid)
            result += "  wpa-psk {s}\n".format(s=self.wpa_psk)

        if self.src == 'dhcp' or self.src == 'loopback':
            return result

        self.validate()

        result += "  address {s}\n".format(s=self.address)
        result += "  netmask {s}\n".format(s=self.netmask)

        if self.gateway:
            result += "  gateway {s}\n".format(s=self.gateway)

        if len(self.dns_nameservers) > 0:
            result += "  dns-nameservers {s}\n".format(s=' '.join(self.dns_nameservers))

        return result

    def validate(self):
        if self.src == 'static':
            if not self.address:
                raise InvalidIface('static interface must have address')
            if not self.netmask:
                raise InvalidIface('static interface must have netmask')
